==> indra-crossdoc-2.1.0-20220119.013303-4-sources.jar: net/kyori/indra/crossdoc/NameBasedProjectDocumentationUrlProviderImpl.java <==
/*
 * This file is part of indra, licensed under the MIT License.
 *
 * Copyright (c) 2020-2021 KyoriPowered
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package net.kyori.indra.crossdoc;

import net.kyori.mammoth.Properties;
import org.jetbrains.annotations.NotNull;

abstract class NameBasedProjectDocumentationUrlProviderImpl implements ProjectDocumentationUrlProvider, NameBasedProjectDocumentationUrlProvider {
  public NameBasedProjectDocumentationUrlProviderImpl() {
  }

  @Override
  public @NotNull String createUrl(final @NotNull String projectName, final @NotNull String projectPath) {
    String actualProjectName = projectName;
    if (this.getProjectNamePrefix().isPresent()) {
      final String prefixToStrip = Properties.finalized(this.getProjectNamePrefix()).get();
      if (actualProjectName.startsWith(prefixToStrip)) {
        actualProjectName = actualProjectName.substring(prefixToStrip.length());
      }
    }

    if (this.getVersion().isPresent()) {
      return actualProjectName + '/' + this.getVersion().get();
    } else {
      return actualProjectName;
    }
  }
}

==> indra-crossdoc-3.0.0-20220919.041625-1-sources.jar: net/kyori/indra/crossdoc/NameBasedProjectDocumentationUrlProviderImpl.java <==
/*
 * This file is part of indra, licensed under the MIT License.
 *
 * Copyright (c) 2020-2022 KyoriPowered
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package net.kyori.indra.crossdoc;

import java.util.Locale;
import net.kyori.mammoth.Properties;
import org.jetbrains.annotations.NotNull;

abstract class NameBasedProjectDocumentationUrlProviderImpl implements ProjectDocumentationUrlProvider, NameBasedProjectDocumentationUrlProvider {
  public NameBasedProjectDocumentationUrlProviderImpl() {
    this.getLowercaseProjectName().convention(false);
  }

  @Override
  public @NotNull String createUrl(final @NotNull String projectName, final @NotNull String projectPath) {
    String actualProjectName = this.normalizeName(projectName);
    if (this.getProjectNamePrefix().isPresent()) {
      final String prefixToStrip = this.normalizeName(Properties.finalized(this.getProjectNamePrefix()).get());
      if (actualProjectName.startsWith(prefixToStrip)) {
        actualProjectName = actualProjectName.substring(prefixToStrip.length());
      }
    }

    if (this.getVersion().isPresent()) {
      return actualProjectName + '/' + this.getVersion().get();
    } else {
      return actualProjectName;
    }
   }

  private String normalizeName(final String name) {
    if (Properties.finalized(this.getLowercaseProjectName()).get()) {
      return name.toLowerCase(Locale.ROOT);
    } else {
      return name;
    }
  }
}
